@@ -28,8 +28,8 @@ my %BUILTINS = (
 	'QName' => {},
 	'NOTATION' => {},
 	'integer' => {},
-	'non-positive-integer' => {},
-	'non-negative-integer' => {},
+	'nonPositiveInteger' => {},
+	'nonNegativeInteger' => {},
 	'positiveInteger' => {},
 	'negativeInteger' => {},
     'long' => {},
@@ -44,8 +44,6 @@ my %BUILTINS = (
 	'NMTOKEN' => {},
 );
 
-# TODO place into appropriate schema and push on schema definitions list
-# in types
 sub START {
 	my $self = shift;
 	my @args = @_;
