@@ -3,6 +3,8 @@ use strict;
 use warnings;
 use Class::Std::Storable;
 
+our $VERSION="2.00_17";
+
 use SOAP::WSDL::XSD::Typelib::Builtin::anyType;
 use SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType;
 use SOAP::WSDL::XSD::Typelib::Builtin::anyURI;
@@ -33,6 +35,8 @@ use SOAP::WSDL::XSD::Typelib::Builtin::long;
 use SOAP::WSDL::XSD::Typelib::Builtin::Name;
 use SOAP::WSDL::XSD::Typelib::Builtin::NCName;
 use SOAP::WSDL::XSD::Typelib::Builtin::negativeInteger;
+use SOAP::WSDL::XSD::Typelib::Builtin::NMTOKEN;
+use SOAP::WSDL::XSD::Typelib::Builtin::NMTOKENS;
 use SOAP::WSDL::XSD::Typelib::Builtin::nonNegativeInteger;
 use SOAP::WSDL::XSD::Typelib::Builtin::nonPositiveInteger;
 use SOAP::WSDL::XSD::Typelib::Builtin::normalizedString;
@@ -136,6 +140,7 @@ as first item in the base class list.
                      - byte
      - double
      - anyURI
+     - NOTATION
      - string
           - normalizedString
               - language
@@ -145,8 +150,9 @@ as first item in the base class list.
                       - IDREF
                           - IDREFS [list]
                       - ENTITY
-              - NMTOKEN
-                  - NMTOKENS [list]
+              - token
+                  - NMTOKEN
+                      - NMTOKENS [list]
 
 =head1 OVERLOADED OPERATORS
 
@@ -199,6 +205,11 @@ Returns true/false in boolean context.
 
 Returns 1 / 0 in numeric context.
 
+boolean objects have a special method for deleteing their value, because 
+calling C<setl_value(undef)> results in the value being set to false.
+
+ $obj->delete_value();
+
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::byte 
 
 byte integer objects. 
@@ -289,6 +300,9 @@ Derived by SOAP::WSDL::XSD::Typelib::Builtin::list.
 
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::normalizedString
 
+Tab, newline and carriage return characters are replaced by whitespace in 
+set_value. 
+
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::NOTATION
 
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::positiveInteger
@@ -299,6 +313,10 @@ Derived by SOAP::WSDL::XSD::Typelib::Builtin::list.
 
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::string
 
+String values are XML-escaped on serialization. 
+
+The following characters are escaped: <, >, &
+
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::time
 
 time values are automatically converted into XML time strings during setting:
