@@ -2,14 +2,6 @@ package SOAP::WSDL::XSD::Typelib::Builtin::float;
 use strict;
 use warnings;
 
-my %pattern_of          :ATTR(:name<pattern> :default<()>);
-my %enumeration_of      :ATTR(:name<enumeration> :default<()>);
-my %whiteSpace_of       :ATTR(:name<whiteSpace> :default<()>);
-my %maxInclusive_of     :ATTR(:name<maxInclusive> :default<()>);
-my %maxExclusive_of     :ATTR(:name<maxExclusive> :default<()>);
-my %minInclusive_of     :ATTR(:name<minInclusive> :default<()>);
-my %minExclusive_of     :ATTR(:name<minExclusive> :default<()>);
-
 # Speed up. Class::Std::new is slow - and we don't need it's functionality...
 BEGIN {
     use Class::Std::Storable;
